==> nextcloud-app-mail-1.3.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/af.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pos",
    "Name" : "Naam",
    "Mail Address" : "Posadres",
    "Password" : "Wagwoord",
    "IMAP Host" : "IMAP-gasheer",
    "None" : "Geen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-poort",
    "IMAP User" : "IMAP-gebruiker",
    "IMAP Password" : "IMAP-wagwoord",
    "SMTP Host" : "SMTP-gasheer",
    "SMTP Port" : "SMTP-poort",
    "SMTP User" : "SMTP-gebruiker",
    "SMTP Password" : "SMTP-wagwoord",
    "Save" : "Stoor",
    "Connect" : "Verbind",
    "Add mail account" : "Voeg posrekening toe",
    "Keyboard shortcuts" : "Sneltoetse",
    "Subject" : "Onderwerp",
    "Sending …" : "Stuur…",
    "Go back" : "Gaan terug",
    "Retry" : "Herprobeer",
    "Message sent!" : "Boodskap gestuur!",
    "Send" : "Stuur",
    "Favorite" : "Gunsteling",
    "Delete" : "Skrap",
    "to" : "aan",
    "Reply" : "Antwoord",
    "Forward" : "Stuur aan",
    "Import into calendar" : "Voer in na kalender",
    "Download attachment" : "Laai aanhangsel af",
    "Unnamed" : "Naamloos",
    "New message" : "Nuwe boodskap",
    "Settings" : "Instellings",
    "Add folder" : "Voeg 'n gids by",
    "Delete account" : "Skrap rekening",
    "Loading …" : "Laai …",
    "Signature" : "Handtekening",
    "General" : "Algemeen",
    "User" : "Gebruiker",
    "Host" : "Gasheer",
    "Port" : "Poort",
    "Search" : "Soek",
    "Refresh" : "Verfris",
    "Connect your mail account" : "Koppel u posrekening",
    "All" : "Alle",
    "Archive" : "Argief",
    "Drafts" : "Konsepte",
    "Favorites" : "Gunstelinge",
    "All inboxes" : "Alle inkassies",
    "Inbox" : "Inkassie",
    "Junk" : "Gemorspos",
    "Sent" : "Gestuur",
    "Trash" : "Asblik",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Forwarding to %s" : "Stuur aan na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
    "Redirect" : "Herverwys",
    "The link leads to %s" : "Die skakel lei na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Indien u nie daardie blad wil besoek nie, kan u na <a href=\"%s\">Pos</a> terugkeer."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.4.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/af.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pos",
    "Name" : "Naam",
    "Mail Address" : "Posadres",
    "Password" : "Wagwoord",
    "IMAP Host" : "IMAP-gasheer",
    "None" : "Geen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-poort",
    "IMAP User" : "IMAP-gebruiker",
    "IMAP Password" : "IMAP-wagwoord",
    "SMTP Host" : "SMTP-gasheer",
    "SMTP Port" : "SMTP-poort",
    "SMTP User" : "SMTP-gebruiker",
    "SMTP Password" : "SMTP-wagwoord",
    "Save" : "Stoor",
    "Connect" : "Verbind",
    "Add mail account" : "Voeg posrekening toe",
    "Keyboard shortcuts" : "Sneltoetse",
    "Subject" : "Onderwerp",
    "Sending …" : "Stuur…",
    "Go back" : "Gaan terug",
    "Retry" : "Herprobeer",
    "Message sent!" : "Boodskap gestuur!",
    "Send" : "Stuur",
    "Favorite" : "Gunsteling",
    "Select" : "Kies",
    "Delete" : "Skrap",
    "Important" : "Belangrik",
    "Favorites" : "Gunstelinge",
    "Other" : "Ander",
    "to" : "aan",
    "Reply" : "Antwoord",
    "Forward" : "Stuur aan",
    "Import into calendar" : "Voer in na kalender",
    "Download attachment" : "Laai aanhangsel af",
    "Unnamed" : "Naamloos",
    "New message" : "Nuwe boodskap",
    "Settings" : "Instellings",
    "Quota" : "Kwota",
    "Add folder" : "Voeg 'n gids by",
    "Remove account" : "Verwyder rekening",
    "Loading …" : "Laai …",
    "Cancel" : "Kanselleer",
    "Signature" : "Handtekening",
    "General" : "Algemeen",
    "User" : "Gebruiker",
    "Host" : "Gasheer",
    "Port" : "Poort",
    "Search" : "Soek",
    "Refresh" : "Verfris",
    "Connect your mail account" : "Koppel u posrekening",
    "All" : "Alle",
    "Archive" : "Argief",
    "Drafts" : "Konsepte",
    "All inboxes" : "Alle inkassies",
    "Inbox" : "Inkassie",
    "Junk" : "Gemorspos",
    "Sent" : "Gestuur",
    "Trash" : "Asblik",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Forwarding to %s" : "Stuur aan na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
    "Redirect" : "Herverwys",
    "The link leads to %s" : "Die skakel lei na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Indien u nie daardie blad wil besoek nie, kan u na <a href=\"%s\">Pos</a> terugkeer."
},
"nplurals=2; plural=(n != 1);");
